Skip to content

Product Feed Apps and Software

Updated: Apr 17, 2026

The Product Feed Apps and Software edge allows you to list app and software items (mobile apps, desktop software, games) that were ingested from a specific product feed.

Permissions

To use this API, your app needs the following permission:

  • catalog_management

Reading

To list app and software items from a product feed, send a GET request:

GET /v25.0/{product-feed-id}/apps_and_software HTTP/1.1
Host: graph.facebook.com

Parameters

ParameterTypeDescription
summarybooleanOptional. When true, includes a summary object with total_count in the response.
limitintegerOptional. Maximum number of items to return per page.
beforestringOptional. Cursor for backward pagination.
afterstringOptional. Cursor for forward pagination.

Fields

A GET request to this edge returns a JSON-formatted result:

{
  "data": [],
  "paging": {},
  "summary": {}
}

data

A list of Apps and Software nodes. See the Apps and Software reference for the full list of fields.

paging

For more details about pagination, see the Graph API guide.

summary

Aggregated information about the edge, such as counts. Specify summary=true as a query parameter to include this in the response.

FieldTypeDescription
total_countintegerTotal number of items in the feed.

Creating

You can't perform this operation on this node. To create product feeds, use the Product Feed node.

Updating

You can't perform this operation on this node. To update product feeds, use the Product Feed node.

Deleting

You can't perform this operation on this node. To delete product feeds, use the Product Feed node.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About